
# WCM Base Installation Profile

The WCM Base installation profile is used to create builds of the WCM Drupal Distribution with drush make. Below are instructions for developing and deploying the distribution.

## Important Files

### [CHANGELOG.txt](CHANGELOG.txt)
Changelog for the distribution and installation profile. All changes made to the profile itself or custom modules and themes, should be entered here, in a human-readable format consistent with that of previous entries. These changes should be reviewed and timestamped before a new build is made.

### [wcm_base.info](wcm_base.info)
Metadata for the installation profile containing dependencies, which are the core, contrib and custom modules, themes and libraries (hereafter referred to as ‘projects’), which are to be enabled upon installation. Only needs modification when projects are added or removed.

### [wcm_base.make](wcm_base.make)
Drush makefile for contrib and custom drupal projects, as well as patches to said projects, to be downloaded when a build is run via drush make. When a contrib project needs to be updated, this is where the version number should be changed. Any time a contrib project is updated, it is possible that existing patches will become incompatible with the updated version and the next build will fail. If this happens, visit the drupal.org issue URL for each patch applied the project and determine if the patch has been accepted and subqequently included in the new version being downloaded. This can be done by checking the date and status of the issue and/or by downloading the patch and attempting to apply it to the updated project manually. If the patch has not been accepted and still does not apply, look for and attempt to test a newer version of the patch on the drupal.org issue, or attempt to re-roll the patch yourself (instructions can be found at [drupal.org/patch](http://drupal.org/patch)). If all else fails, abandon updating the project or seek help from a colleague. Updating contrib projects is rarely urgent, the exception being when security updates are released.

### [build-wcm_base.make](build-wcm_base.make)
Drush makefile for the distribution, containing only the installation profile, to be called when making a production build of the distribution. When using this makefile, the installation profile, and all projects will be downloaded to profiles/wcm_base. Rarely needs modification. Resulting code should be pushed to the [WCM Base Distribution UCR repository](https://code.osu.edu/ocio_odee_web/wcm-base-distro) for deployment. This and the dev makefile below are the only files to be called directly by drush make.

### [build-wcm_base-dev.make](build-wcm_base-dev.make) 
Drush makefile for a local development version of the distribution, to be called instead of the above makefile to build a Drupal environment more suitable for developing custom modules and themes for the distribution, as well as making and testing updates to the installation profile itself. When using this makefile, all projects will be downloaded to sites/all and all custom projects will exist as individual git repositories. When a new custom project is added to the distribution, it should be added to this file to ensure that the project will be downloaded as a git repository.

### [drupal-org-core.make](drupal-org-core.make)
Drush makefile for drupal core, automatically called by the prod and dev build makefiles. Pulls from Pantheon’s Drupal 7 repository with no version number, meaning the latest version of Drupal core will always be downloaded. Contains core patches and pantheon.yml patch file.

### [wcm_base.install](wcm_base.install)
Install file containing basic functions and drupal commands to be run during installation, such as choosing a default theme, setting core variables, and reverting features. All custom functions must be called by wcm_base_install().

### [wcm_base.profile](wcm_base.profile)
Contains additional installation tasks and configuration, including those that may require visibility to or interaction with the installer. Neither this file, nor wcm_base.install, are frequently modified.
    

For more information about Drupal distributions and installation profiles, see [drupal.org/docs/7/creating-distributions](http://drupal.org/docs/7/creating-distributions).

## Development

### Cloning the WCM Base profile

To get started, clone the WCM Base profile in your local web root.

```
git clone git@code.osu.edu:ocio_odee_web/wcm_base.git
```

### Building the codebase

After you've downloaded the most recent version of the profile, build the development site from your web root using the dev makefile.

```
drush make --no-gitinfofile wcm_base/build-wcm_base-dev.make DRUPAL_ROOT
```

Replace `DRUPAL_ROOT` with the name you would like to give to the directory in which your local drupal site will reside. This will not appear in any repositories, so you may use any name you would like. If you do not specify a location, the distribution will be built in the current directory, which you do not want.

The `--no-gitinfofile` flag prevents drush from making changes or adding metadata to your .info files

The build might take couple of minutes, as all of Drupal core must be downloaded, as well as contrib and custom modules and themes.

### Updating the codebase

In order to retrieve updates made to the WCM Base profile, including modules, themes and Drupal core, you will need to update the profile via git.

Since the WMC Base profile was downloaded again within the Drupal site after first running `drush make`, you can simply update it there instead of going back to the one in your web root. This must be done from the `profiles/wcm_base` directory.

```
git pull --rebase
```

After the profile has been updated, run the following from your Drupal root to updated your development codebase, and perform any new database updates.

```
drush make --no-gitinfofile profiles/wcm_base/build-wcm_base-dev.make .
drush updb
```

This will rebuild the site using the parameters defined in the make file. Note that this command must be executed from the Drupal root. While you can generally build from any location and then add a parameter specifying the location where you'd like the files to go, drush will only let you rebuild an existing site from the site root. In this case, we are using the `.` character to target the current directory. This command can be executed without setting a target, but drush will then force you to confirm that you would like to build in the current directory. This confirmation can be skipped by appending the `-y` flag, but unless you want to be asked to confirm the build every time, simply targeting the current directory will circumvent this.

If you are updating a production codebase, you can use the drush remake plugin, which will rebuild the codebase from any location within your Drupal site with a simplified command.

```
drush remake
```

To install this plugin, simple run the following command.

```
drush dl drush_remake
```

This plugin is not recommended for the development environment, as it appears to download everything into profiles instead of sites/all.

**IMPORTANT:** Changes to any files within the Drupal root will be overwritten, so make sure you've committed and pushed changes to custom modules and themes to their corresponding UCR repositories before rebuilding. Existing modules and other files in your local environment will not be deleted however, so if you are testing modules that you have not added to the make file, they will still be there after you rebuild. If you have any local branches, they will be lost, so either push your branch to UCR, merge your changes into an existing branch and push, or simply make a copy of your repository and then move it back into the site after you rebuild. If you're not confident overwriting everything, you can always start a new build in a completely different directory than the one where your existing site lives, but this will require lots of copying and pasting and is very tedious.

The rebuild would normally take a while, as once again, everything needs to be re-downloaded. Fortunately, this is not necessary if you just want to refresh modules and themes. If Drupal core has not been updated in the make file, this is just a waste of time, so in most cases, you can just add the `--no-core` flag.

```
drush make --no-core --no-gitinfofile profiles/wcm_base/build-wcm_base-dev.make .
```

This is significantly faster and usually all that is necessary to get your whole site up to date.

### Installing the profile

If you are installing the WCM Distribution for the first time, then you need to create a new database, configure settings.php, and run the Drupal installer. This can be accomplished by passing your database credentials, the name of the new database you'd like to create, and the name of the site to `drush site-install`, or more simply, `drush si`.

```
drush si wcm_base --db-url='mysql://[db_user]:[db_pass]@localhost/[db_name]' --site-name=Example -y
```

If you don't like the idea of your credentials being visible and appearing in your shell history, this can also be done by creating a new database manually and running the command without any extra parameters. This will require you to create and configure a settings.php file, either manually or through the installation web interface.

```
drush si wcm_base -y
```

Once the settings file has been created and configured for the first time, the shorter command above can also be used at any time to reinstall WCM Base, which will wipe out the site's database and recreate it from scratch.


## Production

### Building the distribution

When updating the distribution repository, you must rebuild the codebase. Before doing this for the first time, you must clone the distrubution repo.

```
git clone git@code.osu.edu:ocio_odee_web/wcm-base-distro.git
```

You should already have a copy of the install profile in your web root, per the first step in the [Development](#cloning-the-wcm-base-profile) section. While you might choose to build from the profile repo that exists in your development site root, using a separate instance prevents conflicts and ensures code integrity. If both the profile and distribution repos exist in your web root directory, you can use the steps below to make a new build.

First, navigate to the profile repo, and do a pull and make sure it is up to date using the `pull` git command. The `reset` command is necessary if local changes have been made which prevent a pull from being successful, though this should rarely, if ever, be the case. There are other git commands, such as `stash`, and `fetch`, which serve similar functions as `reset` and `pull`, but the latter are cleaner, simpler and just as effective.

```
cd wcm_base
git reset --hard HEAD
git pull
```

Next, navigate to the distribution repo, and run the same commands. Then, remove all files in the directory. Note that the `rm` command is highly destructive, as it removes all files within the working directory, so make sure you are in the right location before executing it, though you will be asked to confirm the deletion as a safeguard.

```
cd ../wcm-base-distro
git reset --hard HEAD
git pull
rm -rf *
```

Now, run drush make.

```
drush make ../wcm_base/build-wcm_base.make --no-gitinfofile .
```

Drush make will now run, downloading all custom and contrib drupal projects in the install profile, as well as those specified in makefiles within those projects. Note that if a project is defined in both the install profile and a custom or contrib module, the definition in the install profile will be used. 

If any project fails to download, or if a defined patch fails to apply, an error will appear in the drush make output and the build will fail. Unfortunately, such an error will not stop the build process, so you will need to inspect the output for errors manually. Otherwise, you may think that a build has successfully completed, when it has actually failed.

These commands may be strung together for easier execution. Note that the path to the install profile within the first `cd` command has been modified so that the combo command can be run from within the distribution directory.

```
cd ../wcm_base && git reset --hard HEAD && git pull && cd ../wcm-base-distro && git reset --hard HEAD && git pull && rm -rf * && drush make ../wcm_base/build-wcm_base.make --no-gitinfofile .
```

See [Loose ends and bonus tips](#loose-ends-and-bonus-tips) for tips on how to save this and other commands as shell aliases, which allows them to be reused without having type them out every time.

If the build completes successfully, stage all files in the directory, commit the changes (with a comment) and then push the repo to UCR.

```
git add . 
git commit -m 'weekly build'
git push
```

### Deploying builds to Pantheon

New builds of the distribution are deployed to Pantheon using the [Terminus](https://github.com/pantheon-systems/terminus) command line tool. Terminus is very powerful, but also rather complicated, so a shell script has been written to make deployments simpler. This script is called Aergia, and instructions for its installation and usage can be found on its [UCR page](https://code.osu.edu/ocio_odee_web/aergia).

The command which is generally used to deploy builds to the production environments of all WCM sites is:

```
aergia deploy all -d DRUSH_COMMAND
```

Aergia automatically executes database updates and clears drupal caches, so the Drush flag and argument are usually only necessary if features are being reverted in bulk, but it can be used to run any drush commands. Aergia also includes other commands to assist with testing and deployment, which can be found in that project's README file.

## Loose ends and bonus tips

This might seem complicated, but it's really not so bad. It's unlikely that you will need to rebuild your dev environment on a daily basis if you are working on individual modules, as most changes that matter to you as a developer can also be retrieved directly from the project git repos. A full dev rebuild is necessary to bring your development site up to date, which is most important when updates are made to Drupal core, or if many custom or contrib projects are added or updated. If you're worried about whether changes to your repos will be easily communicated to other team members, remember that any time someone else wants to push to a repo you're working on, they will probably have to pull first, meaning your changes will get to them soon enough. As long as all your changes have been committed, rebuilding should rarely cause any problems.

Here are some additional tips to help you along:

- Typing out all these commands can be tedious, so it's highly recommended to use shell aliases to minimize the inconvenience. This is a common and straightforward practice and is not difficult to do. There are plenty of resources on the subject, but DigitalOcean has [a pretty good one](https://www.digitalocean.com/community/tutorials/an-introduction-to-useful-bash-aliases-and-functions).

- You may also have noticed that the recommended method for updating the WCM is to use the ```--rebase``` flag when executing a `git pull`. This is generally a good practice whenever you pull because it prevents unnecessary merge commits from being added to the git log. You can also configure your local git configuration to always rebase on pull with `git config --bool pull.rebase true`

- You may also may not know the the shell you use from the command line can help you out with keeping track of what's going on with git. [Oh My Zsh](http://ohmyz.sh) is an excellent replacement for the default Bash shell, and includes lots of options and customizations, such as showing you what branch you're on without having to type anything at all, as well as customizing the look and feel of your prompt, and additional enhancements for command line usage and navigation.

### Why a make file instead of a mega git repository?

Development of this distribution could be done by this method above, whereby building a make file downloads core and contrib and pulls down entire working git repos for modules and themes, or by using a repo of the pre-built site, with the smaller repos nested inside of it. There are pros and cons to each approach.

#### Build speed

Rebuilding from the make file is slower than a git pull because every file is downloaded whole instead of just a diff of each changed file. However, the benefit is minimal since Drupal does not need to be updated frequently, and most of the work will be done on custom themes and modules, which will have their own repos, regardless of the method used to build the site. It's true that it is easier to do a quick pull to see if any changes have been made, as opposed to having to rebuild.

#### Ease of common development

With nested repos, changes to modules and themes, which are frequent during early development need to be committed to individual repos and to the larger distribution repo. The introduces the potential human error involving adding and committing the right files to the right repo and adds frequent, unnecessary repetition. With the make file approach, developers need only focus on their version-controlled projects, which are updated automatically upon rebuilding, but can also be pulled manually. New modules and themes can simply be created or downloaded locally and then added to the make file for later distribution. Once they have been added to the make file, committing them to a parent repository becomes unnecessary, as contrib and core modules are never modified.

#### Hands-off updates

Contrib modules, and even Drupal core itself must be updated manually, and then committed to a parent repo. With a make file, the newest version is pulled by default when rebuilding making regular maintenance easier. Specific versions can optionally be added, as well. As a bonus, this will prevent developers from hacking core and contrib due to the fact that any changes they make will be overwritten on the next rebuild.
