<?php
/**
 * @file
 *  Defines tokens for news_client.
 */

/**
 * Implements hook_token_info().
 */
function news_client_token_info() {
  $info = array();
  
  $info['tokens']['node']['news_client_body_summary'] = array(
    'name' => t('News Client:Body Summary'),
    'description' => t('Body summary for the News Client Cached Article.'),
  );
  
  $info['tokens']['node']['news_client_featured_image_url'] = array(
    'name' => t('News Client:Featured Image URL'),
    'description' => t('Featured Image URL for the News Client Cached Article.'),
  );
  
  $info['tokens']['node']['news_client_featured_image_alt'] = array(
    'name' => t('News Client:Featured Image Alt'),
    'description' => t('Featured Image alt text for the News Client Cached Article.'),
  );
  
  $info['tokens']['node']['news_client_social_image_url'] = array(
    'name' => t('News Client:Social Image URL'),
    'description' => t('Social Image URL for the News Client Cached Article.'),
  );
  
  $info['tokens']['node']['news_client_social_image_alt'] = array(
    'name' => t('News Client:Social Image Alt'),
    'description' => t('Social Image alt text for the News Client Cached Article.'),
  );
  
  return $info;
}

/**
 * Implements hook_tokens().
 */
function news_client_tokens($type, $tokens, array $data = array(), array $options = array()) {
  $replacements = array();
  $sanitize = !empty($options['sanitize']);
  
  if ($type == 'node' && !empty($data['node'])) {
    $node = $data['node'];
    
    if ($node->type == 'news_client_cached_article') {
      try {
        $wrapper = entity_metadata_wrapper('node', $node);
        
        foreach ($tokens as $name => $original) {
          switch ($name) {
            case 'news_client_body_summary':
              $summary = $wrapper->news_client_body->summary->value();
              $summary = strip_tags($summary);
              $summary = trim($summary);
              
              if (empty($summary)) {
                $body = $wrapper->news_client_body->value->value();
                $body = strip_tags($body);
                $summary = text_summary($body, NULL, 200);
              }
              
              $replacements[$original] = $summary;
              break;
              
            case 'news_client_featured_image_url' :
              $replacements[$original] = _news_client_image_token_replacements($wrapper, 'news_client_image_json', 'url');
              break;
              
            case 'news_client_featured_image_alt' :
              $replacements[$original] = _news_client_image_token_replacements($wrapper, 'news_client_image_json', 'alt');
              break;
              
            case 'news_client_social_image_url' :
              $social_image_url = _news_client_image_token_replacements($wrapper, 'news_client_social_image_json', 'url');
              
              if (empty($social_image_url)) {
                // If there is no social image url, default to featured image.
                $social_image_url = _news_client_image_token_replacements($wrapper, 'news_client_image_json', 'url');
              }
              
              $replacements[$original] = $social_image_url;
              break;
              
            case 'news_client_social_image_alt' :
              $social_image_alt = _news_client_image_token_replacements($wrapper, 'news_client_social_image_json', 'alt');
              
              if (empty($social_image_alt)) {
                // Check to see if social image url exists.
                $social_image_url = _news_client_image_token_replacements($wrapper, 'news_client_social_image_json', 'url');
                
                if (empty($social_image_url)) {
                  // If no social image was set, then the alt text should default to the featured image alt text if it exists.
                  // (If a social image was set, we don't want the featured image's alt text since it could be a different image.)
                  $social_image_alt = _news_client_image_token_replacements($wrapper, 'news_client_image_json', 'alt');
                }
              }
              
              $replacements[$original] = $social_image_alt;
              break;
          }
        }
      }
      catch (Exception $e) {
        _news_client_entitymetadatawrapper_exception($e);
      }
    }
  }
  
  return $replacements;
}

/**
 * Creates token replacements for an attribute from image field JSON.
 * @param object $wrapper
 * @param string $field_name
 * @return string
 */
function _news_client_image_token_replacements($wrapper, $field_name, $attribute) {
  $image_json = $wrapper->{$field_name}->value();
  $image_array = json_decode($image_json, TRUE);
  $image_data = array();
  
  // news_client_image_json may be empty, and $image_array would be NULL. Test first.
  if (is_array($image_array)) {
    $image_data = array_shift($image_array);
  }
  
  $replacements = isset($image_data[$attribute]) ? $image_data[$attribute] : '';
  
  return $replacements;
}
