(function ($) {

  /**
   * The recommended way for producing HTML markup through JavaScript is to write
   * theming functions. These are similiar to the theming functions that you might
   * know from 'phptemplate' (the default PHP templating engine used by most
   * Drupal themes including Omega). JavaScript theme functions accept arguments
   * and can be overriden by sub-themes.
   *
   * In most cases, there is no good reason to NOT wrap your markup producing
   * JavaScript in a theme function.
   */

  // Focus on webform error messages
  Drupal.behaviors.formErrorFocus = {
    attach: function (context, settings) {
      if ($('.form-error').length) {
        window.location.href = '#error-message';
      }
    }
  };

  // Hide webform required field asterisks from screen readers
  Drupal.behaviors.webformRequired = {
    attach: function (context, settings) {
      $('.webform-component span.form-required').attr('aria-hidden', 'true');
    }
  };

/**
 * CKEditor improperly sets the heading scope on tables with headers set on BOTH the
 * first row and first column. This behavior fixes that.
 */
  Drupal.behaviors.fixTableScope = {
    attach: function (context, settings) {
      $('table').each(function(){
        var firstrow = $(this).find('tr').first();
        var firsthead = firstrow.find('th');
        if (firsthead.size() > 1) {
          firsthead.attr('scope', 'col');
        }
      });
    }
  };

    Drupal.behaviors.slideshowSwipe = {
      attach: function (context, settings) {
      if ($.fn.swipe) {
        $("#block-views-featured-slideshow-block").swipe( {
          swipe:function(event, direction, distance, duration, fingerCount, fingerData) {
            if (direction == 'left' || direction == 'right') {
              var controls = $(this).find('.js-carousel--control--list--item');
              var lastIndex = controls.length - 1;
              var activeIndex = controls.filter('[tabindex="0"]').index();

              if (direction == 'left') {
                activeIndex++;
              }
              else if (direction == 'right') {
                activeIndex--;
              }

              if (activeIndex < 0) {
                activeIndex = lastIndex;
              }
              else if (activeIndex > lastIndex) {
                activeIndex = 0;
              }

              controls.eq(activeIndex).click();
            }
          }
        });
      }
    }
  };

  Drupal.behaviors.wcmOmegaAnchorScroll = {
    attach: function (context, settings) {
      // Scroll to anchors in jQuery UI widgets on page load or if hash in URL changes.
      $(window).on('load hashchange',function() {
        var anchor = window.location.hash;

        // If anchor exists, determine if it lives in a jQuery UI widget.
        if (anchor) {
          var target = $(anchor);

          if (target.parents('.accordion').length) {
            var selector = '.accordion-item';
            var parentPanel = target.parents(selector);
            var header = parentPanel.find('.accordion-header');

            if (header.attr('aria-expanded') != 'true') {
              header.click();

              setTimeout(function(){
                target.focus();
              }, 410);
            }

            /*
            // Scroll to the target anchor (and account for navbar height)
            setTimeout(function(){
             // $('html, body').animate({scrollTop: target.offset().top - $('#navbar-bar').height() * 2}, 0);
            }, 410);
            */

            /*
            if (parent.hasClass('view-content')) {
              selector = '.views-row';
            }*/
          }
          else if (target.parents('.ui-tabs').length) {
            var method = 'tabs';
            var selector = '.ui-tabs-content';
            var parent = target.parents('.ui-widget');
            var parentPanel = target.parents(selector);
            var activeIndex = parent[method]('option', 'active');
            var targetIndex = parent.find(selector).index(parentPanel);

            if (activeIndex != targetIndex || activeIndex === false) {
              // Activate the widget element containing the anchor and recompute panel height.
              parent[method]('option', 'active', targetIndex);

              // Scroll to the target anchor (and account for navbar height)
              setTimeout(function(){
                $('html, body').animate({scrollTop: target.offset().top - $('#navbar-bar').height() * 2}, 0);
              }, 410);
            }
          }
        }
      });

      // Trigger hashchange event if target of clicked link is on the current page (and ignore tab headers)
      $('a').click(function() {
        if (this.hash && window.location.pathname == this.pathname && !$(this).hasClass('ui-tabs-anchor')) {
          $(window).trigger('hashchange');
        }
      });
    }
  };

/*** MatchHeight support ***/
  Drupal.behaviors.wcmOmegaMatchHeights = {
    attach: function (context, settings) {

      if ($.fn.matchHeight) {
        /* Match tile panes to equal height by row */
        var rows = $('.node-type-ocio-landing-page .row-tiles .row-fluid');
        rows.each(function() {
          var resize = false;

          var row = $(this);
          var regions = row.find('.tile-panel');
          regions.each(function(row){

            if ($(this).find('.pane-bundle-tile-pane-plus-text-area, .pane-bundle-tile-pane').size() == 1 ) {
              resize = true;
              return true;
            }
          });

          if (resize) {
            var panes = row.find('.tile-panel .pane-bundle-tile-pane-plus-text-area, .tile-panel .pane-bundle-tile-pane');
            panes.find('.text-areas, .title-box').matchHeight({byRow: false});
            panes.matchHeight({byRow: false});
          }
        });
      }

    }
  };


/*** If browser has no svg support, replace svg images with pngs ***/
  Drupal.behaviors.wcmOmegaSVGFallback = {
    attach: function (context, settings) {

      $('.no-svg img', context).each(function() {
        var src = $(this).attr('src').split('.');
        if (src.pop().toLowerCase() == 'svg') {
          src.push('png');
          $(this).attr('src', src.join('.'));
        }
      });

    }
  };


/*** removes zurb responsive table classes for selected items ***/
  Drupal.behaviors.wcmOmegaExcludeZurb = {
    attach: function (context, settings) {
      //remove for panel panes that are not full width
      $(".panel-display .span3 table").removeClass("responsive");
      $(".panel-display .span4 table").removeClass("responsive");
      $(".panel-display .span6 table").removeClass("responsive");

      //remove for views -- checking with moe first
    }
  };


/*** Adjustments for Media Magnet ***/
  Drupal.behaviors.wcmOmegaMediaMagnet = {
    attach: function (context, settings) {

      /* Move Media Magnet channel icon to title area if only one channel is selected */
      $(document).ajaxSuccess(function( event, request, settings ) {
        if (settings.url.indexOf("mediamagnet.osu.edu/api") >= 0 ) {
          $('.pane-mm-widgets-live-pane.mm-channel-type-undefined').each(function() {
            panel = $(this);
            icons = panel.find('.item i.fa');
            panel.find('.fa-fw').attr('class',function(index, classes) {
              var newClass = icons.first().attr('class').match(/fa-[^\s]+/g);
              if (newClass) {
                panel.removeClass('mm-channel-type-undefined');
                classes = classes.replace('fa-fw', newClass);
                icons.remove();
                $(this).find('.element-invisible').text(newClass);
              }
              return classes;
            });
          });
        }
      });
    }
  };


/*** detects if text panels pane has only a title and adds class of "title-only" ***/
  Drupal.behaviors.wcmOmegaPaneType = {
    attach: function (context, settings) {
      $('.pane-bundle-text').not(':has(.field)').closest('.pane-bundle-text').addClass('title-only');
    }
  };


/*** removes sidebar classes for landing pages - classes were originally added to page div by omega ***/
  Drupal.behaviors.wcmOmegaLandingPage = {
    attach: function (context, settings) {

      if ($("body").hasClass("node-type-ocio-landing-page")) {
        $(".l-page").removeClass("has-one-sidebar has-two-sidebars has-sidebar-1 has-sidebar-2");
      }

    }
  };


/*** hides views-group-header if only one group is chosen in user contact view panes ***/
  Drupal.behaviors.wcmOmegaUserContact = {
    attach: function (context, settings) {

      var group = $('.pane-views-panes .view-content .views-group');
      var group_header = $('.pane-views-panes .view-content .views-group-header');
      var num_groups = group.length;

      if (num_groups == 1) {
        group_header.hide();
      }
    }
  };


/*** adds classes to news client article nodes based on sidebar being empty or not ***/
  Drupal.behaviors.wcmOmegaNewsArticle = {
    attach: function (context, settings) {

      var article = $('.node--full');
      var sidebar = $('.node--article--full .field--name-field-sidebar');
      var sidebar2 = $('.node--news-client-cached-article--full .field--name-news-client-sidebar');

      if(sidebar.length || sidebar2.length) {
        article.addClass('has-sidebar');
      } else {
        article.addClass('no-sidebar');
      }

    }
  };


/*** adjustments for ocio_calendar ***/
  Drupal.behaviors.wcmOmegacalendar = {
    attach: function (context, settings) {

      // if calendar entry node
      if($('.node-type-calendar-entry').length) {
        //find pipe character and assign class
        var pipe ="|";
        var pipeSpan = $('.node-type-calendar-entry .field--name-field-date').html().replace(pipe, '<span class="pipe">' + pipe + '</span>');

        $('.node-type-calendar-entry .field--name-field-date').html(pipeSpan);

        //add font awesome icons
        $('.field--name-field-date').before('<i class="fa fa-calendar" aria-hidden="true"></i>');
        $('.group-location').before('<i class="fa fa-map-marker" aria-hidden="true"></i>');


      } //end if calendar entry node

      // if calendar tags page view
      if ($('body').hasClass('section-calendar-tags')) {
        // alter breadcrumbs on calendar tags views pages
        var pageTitle = $('.l-content h1').text();
        $('.breadcrumb li a[aria-current="page"]').text(pageTitle);

        // alter past-events attachment if no content
        var pastEvents = $('.view-display-id-attachment_1');
        var noResults = $('.view-display-id-attachment_1 .view-empty');
        if (noResults.length) {
          pastEvents.hide();
        }
      }
    }
  };


  /*** adjustments for user_views ***/
  Drupal.behaviors.wcmOmegaUserViews = {
    attach: function (context, settings) {

      //if leadership view pane has an h2.pane-title, change views-group-header from h2 to h3
      var user_pane = $('.pane-leadership-listing-panel-pane-1, .pane-leadership-listing-panel-pane-2, .pane-user-contact-panel-pane-1, .pane-user-contact-panel-pane-2');
      var pane_title = user_pane.find('h2.pane-title');
      var group_header = user_pane.find('h2.views-group-header');

      if(pane_title.length) {

        group_header.each(function() {
          $(this).replaceWith('<h3 class="views-group-header">'+$(this).html()+'</h3>');
        });

      }

    }
  }


})(jQuery);
