<?php

/**
 * @file
 * Contains the theme function override for 'pager_link'.
 */

/**
 * Returns HTML for a link to a specific query result page.
 *
 * @ingroup themeable
 */
function wcm_omega_pager_link($variables) {
  $text = $variables['text'];
  $page_new = $variables['page_new'];
  $element = $variables['element'];
  $parameters = $variables['parameters'];
  $attributes = $variables['attributes'];

  $page = isset($_GET['page']) ? $_GET['page'] : '';
  if ($new_page = implode(',', pager_load_array($page_new[$element], $element, explode(',', $page)))) {
    $parameters['page'] = $new_page;
  }

  $query = array();
  if (count($parameters)) {
    $query = drupal_get_query_parameters($parameters, array());
  }
  if ($query_pager = pager_get_query_parameters()) {
    $query = array_merge($query, $query_pager);
  }

  $hidden = '<span class="element-invisible">';
  $title = $hidden;

  // Set each pager link title.
  if (!isset($attributes['title'])) {
    static $titles = NULL;
    if (!isset($titles)) {
      $titles = array(
        t('« first') => t('first'),
        t('‹ previous') => t('previous'),
        t('next ›') => t('next'),
        t('last »') => t('last'),
      );
    }
    if (isset($titles[$text])) {
      $title .= 'Go to </span>' . filter_xss($text) . $hidden . ' page';
    }
    elseif (is_numeric($text)) {
      $title .= 'Go to page </span>' . filter_xss($text);
    }
  }

  $title .= '</span>';

  // @todo l() cannot be used here, since it adds an 'active' class based on the
  //   path only (which is always the current path for pager links). Apparently,
  //   none of the pager links is active at any time - but it should still be
  //   possible to use l() here.
  // @see http://drupal.org/node/1410574
  $attributes['href'] = url($_GET['q'], array('query' => $query));
  return '<a' . drupal_attributes($attributes) . '>'. t($title)  . '</a>';
}
